@@ -42,10 +42,10 @@ def compute_extra_features(X,sampling):
     feature_list.append(energy_feature_extractor.smv_energy_var())
 
     X_vm_norm = utils.vec2colarr(norm(X, ord=2, axis=1))-1
-    vm_norm_feature_extractor = signal_magnitude.EnergyFeature(X_vm, subwins=30)
+    vm_norm_feature_extractor = signal_magnitude.EnergyFeature(X_vm_norm, subwins=30)
     vm_norm_feature_extractor.get_energies()
-    feature_list.append(vm_norm_feature_extractor.smv_energy_sum())
-    feature_list.append(vm_norm_feature_extractor.smv_energy_var())
+    feature_list.append(vm_norm_feature_extractor.smv_norm_energy_sum())
+    feature_list.append(vm_norm_feature_extractor.smv_norm_energy_var())
 
 
 
