@@ -25,28 +25,19 @@ class OrientationFeature:
                 feature computation''')
             orientation_xyz = np.array([np.nan, np.nan, np.nan])
         else:
-#             gravity = np.array(np.mean(X, axis=0), dtype=np.float)
-#             print(gravity.shape)
-#             gravity_vm = norm(gravity, ord=2, axis=0)
-#             orientation_xyz = np.arccos(
-#                 gravity / gravity_vm) if gravity_vm != 0 else np.zeros_like(gravity)
-#             if unit == 'deg':
-#                 orientation_xyz = np.rad2deg(orientation_xyz)
-            
-            gravity = np.median(X, axis=0)
-            theta = atan(gravity[0] / np.sqrt(np.sum(np.square(np.array(gravity[[1,2]])))) ) * (180 / pi)
-            trident = atan(gravity[1] / np.sqrt(np.sum(np.square(np.array(gravity[[0,2]])))) ) * (180 / pi)
-            phi= atan( np.sqrt(np.sum(np.square(np.array(gravity[[0,1]])))) / gravity[2] ) * (180 / pi) 
-            orientation_xyz = np.array([theta,trident,phi])
-            
-#             theta = atan(gravity[0] / norm(gravity[1:2]) ) * (180 / pi)
-#             trident = atan(gravity[1] / norm(gravity[[0,2]]) ) * (180 / pi)
-#             phi= atan( norm(gravity[0:1])/ gravity[2] ) * (180 / pi) 
-#             orientation_xyz = np.array([theta,trident,phi])
 
-            orientation_xyz = np.array([theta,trident,phi])
-            
-           
+
+            mdn_val = np.median(X, axis=0)
+            x_mdn, y_mdn, z_mdn = mdn_val[0], mdn_val[1], mdn_val[2]
+
+            denom = np.sqrt(x_mdn * x_mdn + y_mdn * y_mdn + z_mdn * z_mdn)
+            x_mdn_norm, y_mdn_norm, z_mdn_norm = x_mdn / denom, y_mdn / denom, z_mdn / denom
+
+            x_ang = acos(x_mdn_norm) * (180 / pi)
+            y_ang = acos(y_mdn_norm) * (180 / pi)
+            z_ang = acos(z_mdn_norm) * (180 / pi)
+            orientation_xyz = np.array([x_ang, y_ang, z_ang])
+
         return vec2rowarr(orientation_xyz)
 
     def estimate_orientation(self, unit='rad'):
