@@ -539,7 +539,7 @@ def correctPredictionsSingleDate(folder, dStr, mode):
     oriDF = pd.DataFrame(data=None)
 
     prevFolder = os.path.join(folder, prevStr)
-    for feature_file in sorted(glob(os.path.join(prevFolder, '*/AndroidWearWatch-AccelerationCalibrated-NA.*.featureOri0to180.csv.gz'))):
+    for feature_file in sorted(glob(os.path.join(prevFolder, '*/*-AccelerationCalibrated-*.featureOri0to180.csv.gz'))):
         odf = pd.read_csv(feature_file, header=0, skiprows=0, sep=',', compression="infer", quotechar='"',
                           parse_dates=['HEADER_TIME_STAMP', 'START_TIME', 'STOP_TIME'],
                           date_parser=mhealth_timestamp_parser)
@@ -547,14 +547,14 @@ def correctPredictionsSingleDate(folder, dStr, mode):
 
 
     thisFolder = os.path.join(folder, dStr)
-    for feature_file in sorted(glob(os.path.join(thisFolder, '*/AndroidWearWatch-AccelerationCalibrated-NA.*.featureOri0to180.csv.gz'))):
+    for feature_file in sorted(glob(os.path.join(thisFolder, '*/*-AccelerationCalibrated-*.featureOri0to180.csv.gz'))):
         odf = pd.read_csv(feature_file, header=0, skiprows=0, sep=',', compression="infer", quotechar='"',
                           parse_dates=['HEADER_TIME_STAMP', 'START_TIME', 'STOP_TIME'],
                           date_parser=mhealth_timestamp_parser)
         oriDF = pd.concat([oriDF, odf], ignore_index=True)
 
     nextFolder = os.path.join(folder, nextStr)
-    for feature_file in sorted(glob(os.path.join(nextFolder, '*/AndroidWearWatch-AccelerationCalibrated-NA.*.featureOri0to180.csv.gz'))):
+    for feature_file in sorted(glob(os.path.join(nextFolder, '*/*-AccelerationCalibrated-*.featureOri0to180.csv.gz'))):
         odf = pd.read_csv(feature_file, header=0, skiprows=0, sep=',', compression="infer", quotechar='"',
                           parse_dates=['HEADER_TIME_STAMP', 'START_TIME', 'STOP_TIME'],
                           date_parser=mhealth_timestamp_parser)
